@@ -6,10 +6,16 @@
 #include  "ZepDraw.h"
 
 
-      integer menu
+      integer menu, icon
 
+      call copenf(11, './Work/.configrc', icon)
+      if(icon  .ne. 0) then
+         configFile='../UserHook/FirstKiss/config' 
+      else
+         read(11, '(a)') configFile
+         close( 11 )
+      endif
 
-      configFile='../UserHook/FirstKiss/config' 
       call epRdNewConfFile
       call cerrorMsg(' ', 1)
       call cerrorMsg(' ', 1)
@@ -24,10 +30,10 @@
          do while(.true.)
             if(menu .eq. 1) then
                if(subdnumber .eq. 0) then
-                  call epExecGene(Det.cmp)
+                  call epExecGene(Det.cmp, Det.nct)
                else
-c                  call epExecGene(SubD(subdnumber).cmp)
-                  call epExecGene(SubdArea(SubD(subdnumber).loc+1))
+                  call epExecGene(SubdArea(SubD(subdnumber).loc+1), 
+     *                            SubD(subdnumber).nct)
                endif
             elseif(menu .gt. 1 .and. menu .le. maxmenu) then
                if(subdnumber .eq. 0) then
@@ -55,6 +61,7 @@ c     **************
 
       call epfixConfig
       call epReadConfig
+      call epMemoCnfgFile
       sellist = ' '
       call epsetDflt     ! set default parameters
       call epsetDflt2
@@ -73,18 +80,17 @@ c     **************
          call cerrorMsg(' ', 1)
          call cerrorMsg('**************************',1)
          write(msg, *)
-     *   ' The  weighted # of components for display = ',
-     *   sum1, ' is too large(>', maxdisplay, ') for quick display.'
+     *   ' The  number of of components for display = ',
+     *   sum1, ' is  large'
          call cerrorMsg(msg, 1)
-         if(clevelmax .gt. 0) then
-            call cerrorMsg(
-     *     'It may be better to restrict the comps. for display',1)
-            call cerrorMsg(' by the levels of the comps.', 1)
+         write(msg, *)
+     *   ' For a slow computer, this may be a burden'
+         call cerrorMsg(msg, 1)
+         write(msg, *)
+     *   ' If so, you may restrict the number of components for display'
+         call cerrorMsg(msg, 1)
+         call cerrorMsg(' by the levels of the comps.', 1)
             call cerrorMsg(' or by other restrictions ', 1)
-         else
-            call cerrorMsg(
-     *       'It is recommended to restrict the comp. for  display',1)
-         endif
          call cerrorMsg('****************************',1)
          call cerrorMsg('Enter return',1)
          read(*,*)
@@ -94,11 +100,12 @@ c     **************
          call cerrorMsg(
      *   '****************************************************',1)
          call cerrorMsg(
-     *    'Some of the components with higher levles will not ',1)
+     *  'You have a large number of components for display', 1)
          call cerrorMsg(
-     *    'be displayed because of too many such components', 1)
+     *  'It may be a burden for a slow computer, so by default',1)
          call cerrorMsg(
-     *    'or too deep level', 1)
+     *    'some of the components with higher levles will not ',1)
+         call cerrorMsg('be displayed.', 1)
          call cerrorMsg(
      *   'You can control the levels for display by menu 14',1)
          call cerrorMsg(
@@ -687,7 +694,7 @@ c            show components which are contained by others
       enddo
       end
 c     ***********************
-      subroutine epExecGene(cmp)
+      subroutine epExecGene(cmp, ncmp)
 c         epexec for subd
       implicit none
 #include  "Zglobalc.h"
@@ -695,8 +702,8 @@ c         epexec for subd
 #include  "Zcnfig.h"
 #include "ZepDraw.h"
 
-
-      record /Component/ cmp(*)
+      integer ncmp
+      record /Component/ cmp(ncmp)
 
       integer klena, i, icon
       logical first, showusage 
@@ -707,9 +714,16 @@ c         epexec for subd
       data showusage/.true./
       save showusage
 
+c      call mediaCount(cmp, matdef, noOfMedia, compnToMn)
+      call mediaCount(cmp, ncmp, matdef, noOfMedia)
       call epOpenMediaFile   ! open media file
-
-      do i = 1, NumComp
+c///////
+      do i = 1, ncmp
+         write(*,*) i, compnToMn(i), matdef(compnToMn(i)),
+     *    Det.Cn2media(i),  Det.cmp(i).matter, cmp(i).matter
+      enddo
+c////////
+      do i = 1, ncmp
          nv = 0
          call epaccept(cmp, i, icon)
          if(icon .ne. 0) goto 500
@@ -1359,17 +1373,15 @@ c         select sub detector
 
       NumComp = SubD(subdnumber).nct
       NumWorld = SubD(subdnumber).nworld
-      nstruc = 0
+      nstruc = 0 
       do i = 1, NumComp
          do j = 1, nstruc
             if(strucarray(j) .eq. 
      *          SubdArea(SubD(subdnumber).loc+i).struc) then
-c     SubD(subdnumber).cmp(i).struc) then
                goto 10
             endif
          enddo
          nstruc = nstruc + 1
-c         strucarray(nstruc) =SubD(subdnumber).cmp(i).struc
          strucarray(nstruc) =
      *        SubdArea( SubD(subdnumber).loc+i ).struc
  10      continue
@@ -1479,7 +1491,7 @@ c    *********************
 
 c         read config file
       call eprcnf(configFile)
-      call mediaCount(matdef, noOfMedia, compnToMn)
+
 
       NumComp = Det.nct
       NumWorld = Det.nworld
@@ -1506,8 +1518,20 @@ c         read config file
          levelc(j) = levelc(j) + w
          maxlevel = max(maxlevel, Det.cmp(i).level)
       enddo
+      call mediaCount(Det.cmp, matdef, noOfMedia, compnToMn)
+      end
+      subroutine epMemoCnfgFile
+c          memorize current config file name in Work/.configrc
+      implicit none
+#include "Zep3Vec.h"
+#include "ZepDraw.h"
+      integer icon
+      call copenfw(21, './Work/.configrc', icon)
+      if(icon  .eq. 0) then
+         write( 21, '(a)' )  configFile
+         close(21)
+      endif
       end
-
       subroutine epOpenMediaFile
       implicit none
 #include "ZepDraw.h"
