@@ -841,16 +841,23 @@ c
 
 c
       real*8 tcomp, tphot, tpair, tgp, tcoh,  t
-      real*8 E, prob, xprob(3), txray(3)
-      real*8  pairmfp, dl, dx, tmpair
-      real*4  xsec(3)  !  coh, incoh,  P.E  1/(g/cm2)
+      real*8 E, prob, xprob(5), txray(5)
+      real*8  pairmfp, dl, dx, tmpair, u
+      real*4  xsec(5)  !  coh, incoh,  P.E  1/(g/cm2)
+      real*8  Excom1, Excom2
       integer icon
+c            where xcom data is used. 
+c       Excom1: compton/photo abs/coherent scat
+c       Excom2: pair; default is  not use xcom
+c              both must be < 100 GeV
+      data Excom1/1.d-3/, Excom2/1.d-3/
+      save Excom1, Excom2
 
       E = cTrack.p.fm.p(4)
       if(E .le. EupperBndCS) then
          xprob(3)= 0.
          if( Media(MediaNo).xcom.size .gt. 0 .and.
-     *        E .lt. 1.0e-3 ) then
+     *        E .lt. Excom1 ) then
 c               below 1MeV, use accurate xs.
             call epXrayp(Media(MediaNo), E,  3,  xprob, txray)
             tcomp=txray(2)
@@ -873,7 +880,15 @@ c               below 1MeV, use accurate xs.
          tcoh = 1.e35
       endif
       if(E .gt. ElowerBndPair) then
-         call epPrSampP(Media(MediaNo), E, prob, tpair)
+         if( Media(MediaNo).xcom.size .gt. 0 .and.
+     *        E .lt. Excom2 ) then
+            call epXrayp(Media(MediaNo), E,  5,  xprob, txray)
+            prob= xprob(4)+xprob(5)
+            call rndc(u)
+            tpair = -log(u)/prob
+         else
+            call epPrSampP(Media(MediaNo), E, prob, tpair)
+         endif
       else
          tpair=1.e35
       endif
